==> picolibc_1.5.1.orig.tar.gz: picolibc-1.5.1/newlib/libm/complex/cexp.c <==
/* $NetBSD: cexp.c,v 1.1 2007/08/20 16:01:34 drochner Exp $ */

/*-
 * Copyright (c) 2007 The NetBSD Foundation, Inc.
 * All rights reserved.
 *
 * This code is derived from software written by Stephen L. Moshier.
 * It is redistributed by the NetBSD Foundation by permission of the author.
 *
 * Redistribution and use in source and binary forms, with or without
 * modification, are permitted provided that the following conditions
 * are met:
 * 1. Redistributions of source code must retain the above copyright
 *    notice, this list of conditions and the following disclaimer.
 * 2. Redistributions in binary form must reproduce the above copyright
 *    notice, this list of conditions and the following disclaimer in the
 *    documentation and/or other materials provided with the distribution.
 *
 * THIS SOFTWARE IS PROVIDED BY THE NETBSD FOUNDATION, INC. AND CONTRIBUTORS
 * ``AS IS'' AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED
 * TO, THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR
 * PURPOSE ARE DISCLAIMED.  IN NO EVENT SHALL THE FOUNDATION OR CONTRIBUTORS
 * BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR
 * CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF
 * SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS
 * INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN
 * CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE)
 * ARISING IN ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE
 * POSSIBILITY OF SUCH DAMAGE.
 *
 * imported and modified include for newlib 2010/10/03 
 * Marco Atzeri <marco_atzeri@yahoo.it>
 */

/*
FUNCTION
        <<cexp>>, <<cexpf>>---complex base-e exponential

INDEX
        cexp
INDEX
        cexpf

SYNOPSIS
       #include <complex.h>
       double complex cexp(double complex <[z]>);
       float complex cexpf(float complex <[z]>);


DESCRIPTION
        These functions compute  the complex base-<[e]> exponential of <[z]>.

        <<cexpf>> is identical to <<cexp>>, except that it performs
        its calculations on <<floats complex>>.

RETURNS
        The cexp functions return the complex base-<[e]> exponential value.

PORTABILITY
        <<cexp>> and <<cexpf>> are ISO C99

QUICKREF
        <<cexp>> and <<cexpf>> are ISO C99

*/


#include <complex.h>
#include <math.h>

double complex
cexp(double complex z)
{
	double complex w;
	double r, x, y;

	x = creal(z);
	y = cimag(z);
	r = exp(x);
	w = r * cos(y) + r * sin(y) * (double complex) I;
	return w;
}

==> picolibc_1.8.10.orig.tar.gz: picolibc-1.8.10/newlib/libm/complex/cexp.c <==
/* $NetBSD: cexp.c,v 1.1 2007/08/20 16:01:34 drochner Exp $ */

/*-
 * Copyright (c) 2007 The NetBSD Foundation, Inc.
 * All rights reserved.
 *
 * This code is derived from software written by Stephen L. Moshier.
 * It is redistributed by the NetBSD Foundation by permission of the author.
 *
 * Redistribution and use in source and binary forms, with or without
 * modification, are permitted provided that the following conditions
 * are met:
 * 1. Redistributions of source code must retain the above copyright
 *    notice, this list of conditions and the following disclaimer.
 * 2. Redistributions in binary form must reproduce the above copyright
 *    notice, this list of conditions and the following disclaimer in the
 *    documentation and/or other materials provided with the distribution.
 *
 * THIS SOFTWARE IS PROVIDED BY THE NETBSD FOUNDATION, INC. AND CONTRIBUTORS
 * ``AS IS'' AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED
 * TO, THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR
 * PURPOSE ARE DISCLAIMED.  IN NO EVENT SHALL THE FOUNDATION OR CONTRIBUTORS
 * BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR
 * CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF
 * SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS
 * INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN
 * CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE)
 * ARISING IN ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE
 * POSSIBILITY OF SUCH DAMAGE.
 *
 * imported and modified include for newlib 2010/10/03 
 * Marco Atzeri <marco_atzeri@yahoo.it>
 */

/*
FUNCTION
        <<cexp>>, <<cexpf>>---complex base-e exponential

INDEX
        cexp
INDEX
        cexpf

SYNOPSIS
       #include <complex.h>
       double complex cexp(double complex <[z]>);
       float complex cexpf(float complex <[z]>);


DESCRIPTION
        These functions compute  the complex base-<[e]> exponential of <[z]>.

        <<cexpf>> is identical to <<cexp>>, except that it performs
        its calculations on <<floats complex>>.

RETURNS
        The cexp functions return the complex base-<[e]> exponential value.

PORTABILITY
        <<cexp>> and <<cexpf>> are ISO C99

QUICKREF
        <<cexp>> and <<cexpf>> are ISO C99

*/


#include <complex.h>
#include <math.h>

double complex
cexp(double complex z)
{
	double r, x, y;

	x = creal(z);
	y = cimag(z);
	r = exp(x);
	return (double complex) (r * cos(y)) + r * sin(y) * (double complex) I;
}
